/* ----------------------------------------------------------------------
   LAMMPS - Large-scale Atomic/Molecular Massively Parallel Simulator
   www.cs.sandia.gov/~sjplimp/lammps.html
   Steve Plimpton, sjplimp@sandia.gov, Sandia National Laboratories

   Copyright (2003) Sandia Corporation.  Under the terms of Contract
   DE-AC04-94AL85000 with Sandia Corporation, the U.S. Government retains
   certain rights in this software.  This software is distributed under 
   the GNU General Public License.

   See the README file in the top-level LAMMPS directory.
------------------------------------------------------------------------- */

#ifndef DUMP_H
#define DUMP_H

#include "stdio.h"
#include "system.h"

class Dump : public System {
 public:
  char *id;                  // user-defined name of Dump
  char *style;               // style of Dump
  int igroup,groupbit;       // group that Dump is performed on

  int scale_flag;            // 1 if atom coords are scaled, 0 if no
  int image_flag;            // 1 if append box count to atom coords, 0 if no
  int header_flag;           // 0 = item, 1 = self-document, 2 = xyz
  int flush_flag;            // 0 if no flush, 1 if flush every dump
  char *format_default;      // default format string
  char *format_user;         // format string set by user
  char *format;              // format string for the file write
  double *buf;               // memory for atom quantities
  FILE *fp;                  // file to write dump to
  int size_one;              // # of quantities for one atom

  Dump(int, char **);
  virtual ~Dump();
  virtual void init() {}
  void write();
  void modify_params(int, char **);

 private:
  int me,nprocs;             // proc info
  int maxbuf;                // size of buf

  virtual void write_header(int) = 0;
  virtual int count() = 0;
  virtual int pack() = 0;
  virtual void write_data(int, double *) = 0;
};

#endif
