/* ----------------------------------------------------------------------
   LAMMPS - Large-scale Atomic/Molecular Massively Parallel Simulator
   www.cs.sandia.gov/~sjplimp/lammps.html
   Steve Plimpton, sjplimp@sandia.gov, Sandia National Laboratories

   Copyright (2003) Sandia Corporation.  Under the terms of Contract
   DE-AC04-94AL85000 with Sandia Corporation, the U.S. Government retains
   certain rights in this software.  This software is distributed under 
   the GNU General Public License.

   See the README file in the top-level LAMMPS directory.
------------------------------------------------------------------------- */

#ifndef DUMP_CUSTOM_H
#define DUMP_CUSTOM_H

#include "dump.h"

class DumpCustom : public Dump {
 public:
  DumpCustom(int, char **);
  ~DumpCustom();
  void init();
  void write_header(int);
  int count();
  int pack();
  void write_data(int, double *);

 private:
  int nmine;                 // # of lines I am dumping
  int *vname;                // name of each vector
  int *vtype;                // type of each vector (INT, DOUBLE)
  char **vformat;            // format string for each vector element

  int ifix_centro;
  int ifix_energy;
  int ifix_stress;

  int fix_create(char *, char **);
  void fix_delete(char *);

  typedef void (DumpCustom::*FnPtrHeader)(int);
  FnPtrHeader header_choice;           // ptr to write header functions
  void header_item(int);
  void header_self(int);
  void header_xyz(int);

  typedef void (DumpCustom::*FnPtrPack)(int);
  FnPtrPack *pack_choice;              // ptrs to pack functions
  void pack_tag(int);
  void pack_type(int);
  void pack_x(int);
  void pack_y(int);
  void pack_z(int);
  void pack_xs(int);
  void pack_ys(int);
  void pack_zs(int);
  void pack_ix(int);
  void pack_iy(int);
  void pack_iz(int);
  void pack_vx(int);
  void pack_vy(int);
  void pack_vz(int);
  void pack_fx(int);
  void pack_fy(int);
  void pack_fz(int);
  void pack_q(int);
  void pack_mux(int);
  void pack_muy(int);
  void pack_muz(int);
  void pack_tqx(int);
  void pack_tqy(int);
  void pack_tqz(int);
  void pack_centro(int);
  void pack_energy(int);
  void pack_sxx(int);
  void pack_syy(int);
  void pack_szz(int);
  void pack_sxy(int);
  void pack_sxz(int);
  void pack_syz(int);
};

#endif
