/* ----------------------------------------------------------------------
   LAMMPS - Large-scale Atomic/Molecular Massively Parallel Simulator
   www.cs.sandia.gov/~sjplimp/lammps.html
   Steve Plimpton, sjplimp@sandia.gov, Sandia National Laboratories

   Copyright (2003) Sandia Corporation.  Under the terms of Contract
   DE-AC04-94AL85000 with Sandia Corporation, the U.S. Government retains
   certain rights in this software.  This software is distributed under 
   the GNU General Public License.

   See the README file in the top-level LAMMPS directory.
------------------------------------------------------------------------- */

#include "string.h"
#include "fix.h"
#include "fix_nvt.h"
#include "fix_npt.h"
#include "fix_temp_rescale.h"
#include "force.h"
#include "temperature.h"
#include "group.h"
#include "comm.h"
#include "error.h"

/* ---------------------------------------------------------------------- */

Fix::Fix(int narg, char **arg)
{
  int n = strlen(arg[0]) + 1;
  id = new char[n];
  strcpy(id,arg[0]);

  igroup = group->find(arg[1]);
  groupbit = group->bitmask[igroup];

  n = strlen(arg[2]) + 1;
  style = new char[n];
  strcpy(style,arg[2]);

  restart_global = 0;
  restart_peratom = 0;
  next_reneighbor = 0;

  // mask settings;

  INITIAL_INTEGRATE = 1;
  PRE_EXCHANGE = 2;
  PRE_NEIGHBOR = 4;
  POST_FORCE = 8;
  FINAL_INTEGRATE = 16;
  END_OF_STEP = 32;
  INITIAL_INTEGRATE_RESPA = 64;
  POST_FORCE_RESPA = 128;
  FINAL_INTEGRATE_RESPA = 256;
}

/* ---------------------------------------------------------------------- */

Fix::~Fix()
{
  delete [] id;
  delete [] style;
}

/* ----------------------------------------------------------------------
   modify a single parameter of a particular Fix
------------------------------------------------------------------------- */

void Fix::modify_params(int narg, char **arg)
{
  if (strcmp(arg[0],"temp") == 0) {
    if (narg != 2) error->all("Illegal fix_modify command");

    int itemp;
    for (itemp = 0; itemp < force->ntemp; itemp++)
      if (strcmp(arg[1],force->templist[itemp]->id) == 0) break;
    if (itemp == force->ntemp) 
      error->all("Could not find fix_modify temp ID");
    if (force->templist[itemp]->igroup != igroup && comm->me == 0)
      error->warning("Group for fix_modify temp != fix group");

    if (strcmp(style,"nvt") == 0)
      ((FixNVT *) this)->set_temp_style(itemp);
    else if (strcmp(style,"npt") == 0)
      ((FixNPT *) this)->set_temp_style(itemp);
    else if (strcmp(style,"temp/rescale") == 0)
      ((FixTempRescale *) this)->set_temp_style(itemp);
    else error->all("Using fix_modify temp with invalid fix style");
    
  } else error->all("Incorrect args in fix_modify command");
}
