/* ----------------------------------------------------------------------
   LAMMPS - Large-scale Atomic/Molecular Massively Parallel Simulator
   www.cs.sandia.gov/~sjplimp/lammps.html
   Steve Plimpton, sjplimp@sandia.gov, Sandia National Laboratories

   Copyright (2003) Sandia Corporation.  Under the terms of Contract
   DE-AC04-94AL85000 with Sandia Corporation, the U.S. Government retains
   certain rights in this software.  This software is distributed under 
   the GNU General Public License.

   See the README file in the top-level LAMMPS directory.
------------------------------------------------------------------------- */

// LAMMPS as a library that can be called from another program

#include "string.h"
#include "system.h"
#include "input.h"

#define CommandInclude
#include "style.h"
#undef CommandInclude

// 3 library function prototypes

void lammps_open(int, char **);     // start-up LAMMPS with command-line args
void lammps_close();                // shut-down LAMMPS
int lammmps_command(char *);        // execute a single command
                                    // return 0 if command executed
                                    // return -1 if LAMMPS exits
                                    // return 1 if caller needs to process
                                    //   "include" and "jump" commands

// 2 variables visible to all 3 library functions

System *sys;
Input *input;

/* ---------------------------------------------------------------------- */

void lammps_open(int argc, char **argv)
{
  sys = new System();
  sys->open(&argc,&argv);
  sys->create();

  input = new Input();
  input->initvar(argc,argv);
}

/* ---------------------------------------------------------------------- */

void lammps_close()
{
  sys->destroy();
  sys->close();
}

/* ---------------------------------------------------------------------- */

int lammps_command(char *str)
{
  char *command = input->one(str);
  if (command == NULL) return 0;

  if (strcmp(command,"exit") == 0) return -1;
  if (strcmp(command,"include") == 0) return 1;
  if (strcmp(command,"jump") == 0) return 1;

  if (0) return 0;

#define CommandClass
#define CommandStyle(key,Class) \
  else if (strcmp(command,#key) == 0) { \
    Class key; \
    key.command(input->narg,input->arg); \
  }
#include "style.h"
#undef CommandClass

  return 0;
}
