/* ----------------------------------------------------------------------
   LAMMPS - Large-scale Atomic/Molecular Massively Parallel Simulator
   www.cs.sandia.gov/~sjplimp/lammps.html
   Steve Plimpton, sjplimp@sandia.gov, Sandia National Laboratories

   Copyright (2003) Sandia Corporation.  Under the terms of Contract
   DE-AC04-94AL85000 with Sandia Corporation, the U.S. Government retains
   certain rights in this software.  This software is distributed under 
   the GNU General Public License.

   See the README file in the top-level LAMMPS directory.
------------------------------------------------------------------------- */

#ifndef PAIR_H
#define PAIR_H

#include "system.h"

class Pair : public System {
 public:
                                       // used by other classes
  double cutforce;                     // max cutoff for all atom pairs
  double eng_vdwl,eng_coul;            // accumulated energies
  double virial[6];                    // accumulated virial

                                       // common to all pair classes
  int allocated;                       // 0/1 = whether arrays are allocated
  int **setflag;                       // 0/1 = whether each i,j has been set
  double **cutsq;                      // max cutoff sq for each atom pair

                                       // pair modify settings
  int offset_flag,mix_flag;            // flags for offset and mixing
  int ncoultablebits;                  // size of Coulomb table
  double tabinner;                     // inner cutoff for Coulomb table

  struct One {                         // single interaction between 2 atoms
    double fforce;
    double eng_vdwl,eng_coul;
    double fx,fy,fz;
    double tix,tiy,tiz,tjx,tjy,tjz;
  };

  Pair();
  virtual ~Pair() {}

  void modify_params(int, char **);
  void init();
  double mix_energy(double, double, double, double);
  double mix_distance(double, double);
  void virial_compute();
  void write_file(int, char **);
  void init_bitmap(double, double, int, int &, int &, int &, int &);

  virtual void compute(int, int) = 0;
  virtual void settings(int, char **) = 0;
  virtual void coeff(int, char **) = 0;
  virtual double init_one(int, int) {return 0.0;}
  virtual void init_style() {}
  virtual void write_restart(FILE *) = 0;
  virtual void read_restart(FILE *) = 0;
  virtual void write_restart_settings(FILE *) = 0;
  virtual void read_restart_settings(FILE *) = 0;
  virtual void single(int, int, int, int,
		      double, double, double, int, One &) = 0;

  virtual void compute_inner() {}
  virtual void compute_middle() {}
  virtual void compute_outer(int, int) {}

  virtual int pack_comm(int, int *, double *, int *) {return 0;}
  virtual void unpack_comm(int, int, double *) {}
  virtual int pack_reverse_comm(int, int, double *) {return 0;}
  virtual void unpack_reverse_comm(int, int *, double *) {}
};

#endif
