/* ----------------------------------------------------------------------
   LAMMPS - Large-scale Atomic/Molecular Massively Parallel Simulator
   www.cs.sandia.gov/~sjplimp/lammps.html
   Steve Plimpton, sjplimp@sandia.gov, Sandia National Laboratories

   Copyright (2003) Sandia Corporation.  Under the terms of Contract
   DE-AC04-94AL85000 with Sandia Corporation, the U.S. Government retains
   certain rights in this software.  This software is distributed under 
   the GNU General Public License.

   See the README file in the top-level LAMMPS directory.
------------------------------------------------------------------------- */

#ifndef PAIR_HYBRID_H
#define PAIR_HYBRID_H

#include "stdio.h"
#include "pair.h"
#include "pair_soft.h"
#include "pair_eam.h"

class PairHybrid : public Pair {
  friend class Force;
  friend class Pair;

 public:
  PairHybrid();
  ~PairHybrid();
  void compute(int, int);
  void settings(int, char **);
  void coeff(int, char **);
  double init_one(int, int);
  void init_style();
  void write_restart(FILE *);
  void read_restart(FILE *);
  void write_restart_settings(FILE *) {}
  void read_restart_settings(FILE *) {}
  void single(int, int, int, int, double, double, double, int, One &);

 private:
  int nstyles;                  // # of different pair styles
  Pair **styles;                // class list for each Pair style
  char **keywords;              // keyword for each Pair style
  int **map;                    // which style each itype,jtype points to

  PairSoft *softstyle;
  PairEAM *eamstyle;
  int eammap,dipoleflag;

  void allocate();
};

#endif
