/* ----------------------------------------------------------------------
   LAMMPS - Large-scale Atomic/Molecular Massively Parallel Simulator
   www.cs.sandia.gov/~sjplimp/lammps.html
   Steve Plimpton, sjplimp@sandia.gov, Sandia National Laboratories

   Copyright (2003) Sandia Corporation.  Under the terms of Contract
   DE-AC04-94AL85000 with Sandia Corporation, the U.S. Government retains
   certain rights in this software.  This software is distributed under 
   the GNU General Public License.

   See the README file in the top-level LAMMPS directory.
------------------------------------------------------------------------- */

#include "mpi.h"
#include "stdio.h"
#include "string.h"
#include "temp_full.h"
#include "atom.h"
#include "force.h"
#include "group.h"
#include "error.h"

/* ---------------------------------------------------------------------- */

TempFull::TempFull(int narg, char **arg) : Temperature(narg, arg)
{
}

/* ---------------------------------------------------------------------- */

void TempFull::init()
{
  count_atoms();
  count_fix();
  dof = force->dimension * ncount;
  dof -= extra_dof + fix_dof;
  if (ncount > 0) tfactor = force->mvv2e / (dof * force->boltz);
  else tfactor = 0.0;
}

/* ---------------------------------------------------------------------- */

double TempFull::compute()
{
  double **v = atom->v;
  double *mass = atom->mass;
  int *type = atom->type;
  int *mask = atom->mask;
  int nlocal = atom->nlocal;

  double t = 0.0;
  for (int i = 0; i < nlocal; i++)
    if (mask[i] & groupbit)
      t += (v[i][0]*v[i][0] + v[i][1]*v[i][1] + v[i][2]*v[i][2]) * 
	mass[type[i]];

  double t_all;
  MPI_Allreduce(&t,&t_all,1,MPI_DOUBLE,MPI_SUM,world);
  t_all *= tfactor;
  return t_all;
}
