/* ----------------------------------------------------------------------
   LAMMPS - Large-scale Atomic/Molecular Massively Parallel Simulator
   www.cs.sandia.gov/~sjplimp/lammps.html
   Steve Plimpton, sjplimp@sandia.gov, Sandia National Laboratories

   Copyright (2003) Sandia Corporation.  Under the terms of Contract
   DE-AC04-94AL85000 with Sandia Corporation, the U.S. Government retains
   certain rights in this software.  This software is distributed under 
   the GNU General Public License.

   See the README file in the top-level LAMMPS directory.
------------------------------------------------------------------------- */

#include "string.h"
#include "update.h"
#include "neighbor.h"
#include "force.h"
#include "output.h"
#include "verlet.h"
#include "respa.h"
#include "error.h"

//#define MinInclude
//#include "style.h"
//#undef MinInclude

/* ---------------------------------------------------------------------- */

Update::Update()
{
  int n;
  char *str;

  ntimestep = 0;

  unit_style = NULL;
  set_units("lj");

  str = "verlet";
  n = strlen(str) + 1;
  integrate_style = new char[n];
  strcpy(integrate_style,str);
  integrate = new Verlet(0,NULL);

  //  str = "cg";
  //n = strlen(str) + 1;
  //minimize_style = new char[n];
  //strcpy(minimize_style,str);
  //minimize = new MinCG();
}

/* ---------------------------------------------------------------------- */

Update::~Update()
{
  delete [] unit_style;

  delete [] integrate_style;
  delete integrate;

  //delete [] minimize_style;
  //delete minimize;
}

/* ---------------------------------------------------------------------- */

void Update::init()
{
  firststep = ntimestep;
  laststep = firststep + nsteps;

  // only init the class that will be invoked by run,minimize,temper

  if (whichflag == 0) integrate->init();
  //else if (whichflag == 1) minimize->init();
}

/* ---------------------------------------------------------------------- */

void Update::set_units(char *style)
{
  if (strcmp(style,"lj") == 0) {
    force->boltz = 1.0;
    force->mvv2e = 1.0;
    force->ftm2v = 1.0;
    force->nktv2p = 1.0;
    force->qqr2e = 1.0;
    dt = 0.005;
    neighbor->skin = 0.3;

  } else if (strcmp(style,"real") == 0) {
    force->boltz = 0.001987191;
    force->mvv2e = 48.88821 * 48.88821;
    force->ftm2v = 1.0 / 48.88821 / 48.88821;
    force->nktv2p = 68589.796;
    force->qqr2e = 332.0636;
    dt = 1.0;
    neighbor->skin = 2.0;

  } else if (strcmp(style,"metal") == 0) {
    force->boltz = 8.617e-5;
    force->mvv2e = 1.0365e-4;
    force->ftm2v = 1 / 1.0365e-4;
    force->nktv2p = 1.602e6;
    force->qqr2e = 14.40659;
    dt = 0.001;
    neighbor->skin = 2.0;
  } else error->all("Illegal units command");

  delete [] unit_style;
  int n = strlen(style) + 1;
  unit_style = new char[n];
  strcpy(unit_style,style);
}

/* ---------------------------------------------------------------------- */

void Update::create_integrate(int narg, char **arg)
{
  if (narg < 1) error->all("Illegal run_style command");

  delete [] integrate_style;
  delete integrate;

  if (strcmp(arg[0],"verlet") == 0)
    integrate = new Verlet(narg-1,&arg[1]);
  else if (strcmp(arg[0],"respa") == 0)
    integrate = new Respa(narg-1,&arg[1]);
  else error->all("Illegal run style");

  int n = strlen(arg[0]) + 1;
  integrate_style = new char[n];
  strcpy(integrate_style,arg[0]);
}

/* ---------------------------------------------------------------------- */

/*
void Update::create_minimize(char *style)
{
  delete [] minimize_style;
  delete minimize;

  if (strcmp(style,"none") == 0) error->all("Illegal minimize style");

#define MinClass
#define MinStyle(key,Class) \
  else if (strcmp(style,#key) == 0) minimize = new Class();
#include "style.h"
#undef MinClass

  else error->all("Illegal minimize style");

  int n = strlen(style) + 1;
  minimize_style = new char[n];
  strcpy(minimize_style,style);
}
*/
