/* ----------------------------------------------------------------------
   LAMMPS - Large-scale Atomic/Molecular Massively Parallel Simulator
   www.cs.sandia.gov/~sjplimp/lammps.html
   Steve Plimpton, sjplimp@sandia.gov, Sandia National Laboratories

   Copyright (2003) Sandia Corporation.  Under the terms of Contract
   DE-AC04-94AL85000 with Sandia Corporation, the U.S. Government retains
   certain rights in this software.  This software is distributed under 
   the GNU General Public License.

   See the README file in the top-level LAMMPS directory.
------------------------------------------------------------------------- */

#ifndef VELOCITY_H
#define VELOCITY_H

#include "system.h"

class Temperature;
class RanPark;

class Velocity : public System {
 public:
  Velocity() {}
  ~Velocity() {}
  void command(int, char **);

 private:
  int igroup,groupbit;
  int style;
  int temp_flag;             // 0 if use default temp, 1 if set by user
  int dist_flag;
  int sum_flag;
  int momentum_flag;
  int rotation_flag;
  int loop_flag;
  int scale_flag;
  double xscale,yscale,zscale;
  Temperature *temperature;

  void create(int, char **);
  void set(int, char **);
  void scale(int, char **);
  void ramp(int, char **);
  void zero(int, char **);

  void rescale(double, double);
  void zero_momentum();
  void zero_rotation();

  void options(int, char **);
  void triple(double, double, double, double *, double *, double *,
	      int, RanPark *);
};

#endif
